@@ -29,13 +29,7 @@ impl Helm {
         }
     }
 
-    pub(crate) async fn execute(
-        &self,
-        cluster: &v0::Cluster,
-        kube_context: &str,
-        namespace: &str,
-    ) -> io::Result<(String, String)> {
-        let commands = self.command(cluster, Some(kube_context), namespace);
+    pub(crate) async fn execute(&self, commands: Vec<Command>) -> io::Result<(String, String)> {
         let (stdout, stderr) = match self {
             Helm::Skip { .. } => (
                 String::new(),
@@ -60,7 +54,7 @@ impl Helm {
         Ok((stdout, stderr))
     }
 
-    pub(crate) fn command(
+    pub(crate) fn install_command(
         &self,
         cluster: &v0::Cluster,
         kube_context: Option<&str>,
@@ -91,6 +85,29 @@ impl Helm {
             .collect()
     }
 
+    pub(crate) fn uninstall_command(
+        &self,
+        cluster: &v0::Cluster,
+        kube_context: Option<&str>,
+        namespace: &str,
+    ) -> Vec<Command> {
+        cluster
+            .helm
+            .iter()
+            .map(|helm| {
+                let mut cmd = Command::new("helm");
+                cmd.arg("uninstall")
+                    .arg(&helm.chart)
+                    .arg("--namespace")
+                    .arg(namespace);
+                if let Some(kube_context) = kube_context {
+                    cmd.arg("--kube-context").arg(kube_context);
+                }
+                cmd
+            })
+            .collect()
+    }
+
     async fn exec(&self, command: Command) -> io::Result<(ExitStatus, String, String)> {
         let output = AsyncCmd::from(command).output().await?;
         let stdout = String::from_utf8_lossy(&output.stdout).trim().to_string();
