@@ -6,6 +6,7 @@
 use std::collections::HashMap;
 use std::fmt;
 use std::io;
+use std::str;
 
 use anyhow::Context;
 use console::{Style, Term};
@@ -71,6 +72,10 @@ pub(crate) struct Cli {
 enum Command {
     #[structopt(about = "Authenticate against statehub service", display_order(0))]
     Login,
+
+    #[structopt(about = "Get entity info")]
+    Get { entity: Entity },
+
     #[structopt(
         about = "Create new state",
         aliases = &["create-st", "cs"],
@@ -215,6 +220,8 @@ enum Command {
             visible_alias = "ctx"
         )]
         context: Option<String>,
+        #[structopt(help = "Skip running 'helm uninstall'", long)]
+        skip_helm: bool,
     },
 
     #[structopt(
@@ -558,10 +565,17 @@ enum Command {
     SelfUpdate,
 }
 
+#[derive(Clone, Copy, Debug, PartialEq)]
+enum Entity {
+    Clusters,
+    States,
+}
+
 impl Command {
     fn requires_api_access(&self) -> bool {
         match self {
             Command::Login => false,
+            Command::Get { .. } => true,
             Command::CreateState { .. } => true,
             Command::DeleteState { .. } => true,
             Command::ListStates => true,
@@ -625,6 +639,10 @@ impl Cli {
 
         match self.command {
             Command::Login => statehub.login().await,
+            Command::Get { entity } => match entity {
+                Entity::Clusters => statehub.list_clusters().await,
+                Entity::States => statehub.list_states().await,
+            },
             Command::CreateState {
                 name,
                 owner,
@@ -635,7 +653,7 @@ impl Cli {
                     .create_state(name, owner, locations, clusters)
                     .await
             }
-            Command::DeleteState { name: state } => statehub.delete_state(state).await,
+            Command::DeleteState { name } => statehub.delete_state(name).await,
             Command::ListStates => statehub.list_states().await,
             Command::ShowState { name } => statehub.show_state(&name).await,
             Command::RegisterCluster {
@@ -703,12 +721,14 @@ impl Cli {
                 force,
                 name,
                 context,
+                skip_helm,
             } => {
                 let names = vec![name];
                 let contexts = context.into_iter().collect();
                 let kubectls = k8s::Kubectl::with_names_and_contexts(names, contexts)?;
+                let helm = k8s::Helm::new(skip_helm);
 
-                statehub.unregister_cluster(kubectls, force).await
+                statehub.unregister_cluster(kubectls, helm, force).await
             }
             Command::UpdateCluster {
                 name,
@@ -1056,13 +1076,14 @@ impl StateHub {
     async fn unregister_cluster(
         &self,
         kubectls: Vec<k8s::Kubectl>,
+        helm: k8s::Helm,
         force: bool,
     ) -> anyhow::Result<()> {
         if force || self.confirm("Are you sure?") {
             log::info!("Make sure all the pods using statehub are terminated");
             log::info!("Uninstall helm");
             for kubectl in kubectls {
-                self.unregister_cluster_helper(kubectl).await?;
+                self.unregister_cluster_helper(kubectl, helm).await?;
             }
         }
         Ok(())
@@ -1435,3 +1456,17 @@ impl StateHub {
             .interact_text_on(&self.stdout)
     }
 }
+
+impl str::FromStr for Entity {
+    type Err = anyhow::Error;
+
+    fn from_str(s: &str) -> Result<Self, Self::Err> {
+        if s.starts_with("cluster") {
+            Ok(Self::Clusters)
+        } else if s.starts_with("state") {
+            Ok(Self::States)
+        } else {
+            anyhow::bail!("Supported entities are 'clusters' and 'states'")
+        }
+    }
+}
