@@ -9,6 +9,7 @@ use std::path::PathBuf;
 
 use anyhow::Context;
 use chrono::Duration;
+use console::Style;
 use serde::{Deserialize, Serialize};
 
 use self::v1::Config as ConfigV1;
@@ -51,6 +52,13 @@ impl Config {
         self.config.token(self.profile.as_deref())
     }
 
+    pub(crate) fn style(&self) -> Style {
+        self.config
+            .color(self.profile.as_deref())
+            .map(Style::from_dotted_str)
+            .unwrap_or_default()
+    }
+
     pub(crate) fn optionally_management_api(self, api: Option<String>) -> Self {
         let Self {
             profile,
